﻿#region File Header

/* File Name    : FacebookException.cs
 * Description  : This class represents the exception that is thrown when a Facebook exception/error occurs.
 * Log
 * Date             Author              Description
 * 15-Oct-2011      Robin Jome          Created the class
 */

#endregion

#region Namespaces

using System;
using System.Net;
using FacebookAPI.FacebookProperties;

#endregion

namespace FacebookAPI.Base
{
    #region Class

    /// <summary>
    /// This class represents the exception that is thrown when a Facebook exception/error occurs.
    /// </summary>
    public class FacebookException : WebException
    {
        #region Properties

        FacebookError FacebookError { get; set; }

        #endregion

        #region Constructors

        /// <summary>
        /// Represents the exception that is thrown when a Facebook exception/error occurs
        /// </summary>
        public FacebookException()
            : base()
        {
        }

        /// <summary>
        /// Represents the exception that is thrown when a Facebook exception/error occurs
        /// </summary>
        /// <param name="message">Represents the exception message</param>
        public FacebookException(string message)
            : base(message)
        {
        }

        /// <summary>
        /// Represents the exception that is thrown when a Facebook exception/error occurs
        /// </summary>
        /// <param name="message">Represents the exception message</param>
        /// <param name="innerException">Represents the inner exception</param>
        public FacebookException(string message, Exception innerException)
            : base(message, innerException)
        {
        }

        public FacebookException(string message, WebExceptionStatus status)
            : base(message, status)
        {
        }

        public FacebookException(string message, Exception exception, WebExceptionStatus status, WebResponse response)
            : base(message, exception, status, response)
        {
        }

        public FacebookException(string message, Exception exception, WebExceptionStatus status, WebResponse response,FacebookError error)
            : base(message, exception, status, response)
        {
            this.FacebookError = error;
        }

        #endregion
    }

    #endregion
}
