﻿internal enum FacebookConnections
{
    Events,
    Feed,
    Comments,
    Invited,
    Declined,
    Attending,
    NoReply,
    MayBe,
    Picture,
    Likes,
    Accounts,
    Questions,
    Options,
    Votes,
    Notes,
    FriendLists,
    Members
}

/// <summary>
/// The types of Facebook events used
/// </summary>
public enum FacebookPrivacyTypes
{
    /// <summary>
    /// Events that are available to every one. Anyone can invite and take part in these events.
    /// </summary>
    OPEN,
    /// <summary>
    /// Available to invites only.
    /// </summary>
    SECRET,
    /// <summary>
    /// Available to friends. Only owner can invite. But visible to public
    /// </summary>
    CLOSED
}

/// <summary>
/// Represents the RSVP statuses for an event in Facebook
/// </summary>
public enum RSVPStatus
{
    /// <summary>
    /// Attending the event
    /// </summary>
    Attending,
    /// <summary>
    /// Maybe attending
    /// </summary>
    MayBe,
    /// <summary>
    /// Not attending the event
    /// </summary>
    Declined,
    /// <summary>
    /// Haven't replied
    /// </summary>
    NoReply
}

/// <summary>
/// Privacy values for a Facebook post. Represents who all can access a post
/// </summary>
public enum PostPrivacyValues
{
    /// <summary>
    /// Everyone can access
    /// </summary>
    EVERYONE,
    /// <summary>
    /// Only friends can access
    /// </summary>
    ALL_FRIENDS,
    /// <summary>
    /// Friends in networks can access
    /// </summary>
    NETWORKS_FRIENDS,
    /// <summary>
    /// Friends and friends of friends can access
    /// </summary>
    FRIENDS_OF_FRIENDS,
    /// <summary>
    /// Facebook custom settings
    /// </summary>
    CUSTOM,
    /// <summary>
    /// Only the user can access
    /// </summary>
    SELF
}

/// <summary>
/// Values to be used if the privacy setting for a post is set to CUSTOM
/// </summary>
public enum PostPrivacyCustomValues
{
    /// <summary>
    /// Everyone can access
    /// </summary>
    EVERYONE,
    /// <summary>
    /// Network of friends can access
    /// </summary>
    NETWORKS_FRIENDS,
    /// <summary>
    /// Friends and Friends of friends can access
    /// </summary>
    FRIENDS_OF_FRIENDS,
    /// <summary>
    /// All friends can access
    /// </summary>
    ALL_FRIENDS,
    /// <summary>
    /// Some of the friends mentioned can access
    /// </summary>
    SOME_FRIENDS,
    /// <summary>
    /// Only me
    /// </summary>
    SELF,
    /// <summary>
    /// No friends can access
    /// </summary>
    NO_FRIENDS
}
