﻿#region File Header

/* File Name    : Comment.cs
 * Description  : A comment on a Graph API object
 * Log
 * Date             Author              Description
 * 15-Oct-2011      Robin Jome          Created the class
 * 19-Oct-2011      Robin Jome          GetPostData() method added
 */

#endregion

#region Namespaces

using System;
using System.Text;
using FacebookAPI.FacebookProperties;

#endregion

namespace FacebookAPI.Objects
{
    #region Class

    /// <summary>
    /// A comment on a Graph API object
    /// </summary>
    public class Comment
    {
        #region Properties

        /// <summary>
        /// Gets the value of Id
        /// </summary>
        /// <value>The Id of the Facebook comment</value>
        public string Id { get; set; }

        /// <summary>
        /// Gets the value of From
        /// </summary>
        /// <value>The user that created the comment</value>
        /// <permission>generic access_token</permission>
        public FacebookBaseObject From { get; set; }

        /// <summary>
        /// Gets or sets the value of Message
        /// </summary>
        /// <value>The comment text</value>
        /// <permission>generic access_token</permission>
        public string Message { get; set; }

        /// <summary>
        /// Gets the value of Created_Time
        /// </summary>
        /// <value>The DateTime the comment was created</value>
        /// <permission>generic access_token</permission>
        public DateTime Created_Time { get; set; }

        /// <summary>
        /// Gets the value of Likes
        /// </summary>
        /// <value>The number of times this comment was liked</value>
        /// <permission>generic access_token</permission>
        public int Likes { get; set; }

        /// <summary>
        /// Gets the value of User_Likes
        /// </summary>
        /// <value>This field is returned only if the authenticated user likes this comment</value>
        /// <permission>generic access_token</permission>
        public string User_Likes { get; set; }

        #endregion

        #region Methods

        /// <summary>
        /// Returns the data to be submitted in a POST request.
        /// </summary>
        /// <returns>Returns the data to be submitted in a POST request.</returns>
        internal string GetPostData()
        {
            StringBuilder postData = new StringBuilder();
            postData.Append("message=").Append(Message);
            return postData.ToString();
        }

        #endregion
    }

    #endregion
}
