﻿#region File Header

/* File Name    : StatusMessage.cs
 * Description  : A status message on a user's wall as represented in the Graph API.
 * Log
 * Date             Author              Description
 * 15-Oct-2011      Robin Jome          Created the class
 * 19-Oct-2011      Robin Jome          GetPostData() method added
 */

#endregion

#region Namespaces

using System.Text;
using FacebookAPI.FacebookProperties;

#endregion

namespace FacebookAPI.Objects
{
    #region Class

    /// <summary>
    /// A status message on a user's wall as represented in the Graph API.
    /// </summary>
    public class StatusMessage
    {
        #region Class

        /// <summary>
        /// Gets or sets the value of Id
        /// </summary>
        /// <value>The Id of the status message</value>
        public string Id { get; set; }

        /// <summary>
        /// Gets the value of From
        /// </summary>
        /// <value>The user who posted the message</value>
        public FacebookBaseObject From { get; set; }

        /// <summary>
        /// Gets or sets the value of Message
        /// </summary>
        /// <value>The status message ID</value>
        public string Message { get; set; }

        /// <summary>
        /// Gets the value of Updated_Time
        /// </summary>
        /// <value>The time the message was published</value>
        public string Updated_Time { get; set; }

        /// <summary>
        /// Gets the value of Type
        /// </summary>
        /// <value>The object type which is set to status</value>
        public string Type { get; set; }

        #endregion

        #region Methods

        /// <summary>
        /// Returns the data to be submitted in a POST request.
        /// </summary>
        /// <returns>Returns the data to be submitted in a POST request.</returns>
        internal string GetPostData()
        {
            StringBuilder postData = new StringBuilder();
            postData.Append("message=").Append(Message);
            return postData.ToString();
        }

        #endregion
    }

    #endregion
}
